#include "SimpleString.h"
#include <iostream>
#include <string>

void Check(bool condition, const std::string& message) {
    if (condition) {
        std::cout << "[PASS] " << message << std::endl;
    } else {
        std::cerr << "[FAIL] " << message << std::endl;
    }
}


/*
    These are a simple set of tests, you should feel free to add more to these to help increase your confidence
    in how your code behaves!
*/

int main() {
    std::cout << "Running SimpleString tests...\n";

    // Test default constructor
    SimpleString s1;
    Check(s1.Length() == 0, "Default constructor should create empty string");
    Check(s1 == SimpleString(""), "Default string should equal empty string");

    // Test constructor from C-string
    SimpleString s2("Hello");
    Check(s2.Length() == 5, "Constructor from C-string should set correct length");
    Check(s2 == SimpleString("Hello"), "Constructor should copy C-string");

    // Test copy constructor
    SimpleString s3 = s2;
    Check(s3.Length() == 5, "Copy constructor should copy length");
    Check(s3 == s2, "Copy constructor should copy string data");

    // Modify s3 to ensure deep copy
    s3 = SimpleString("World");
    Check(s2 == SimpleString("Hello"), "Original string should remain unchanged after copy is modified");
    Check(s3 == SimpleString("World"), "Copied string should be updated");

    // Test assignment operator
    SimpleString s4("Temp");
    s4 = s2;
    Check(s4.Length() == 5, "Assignment operator should copy length");
    Check(s4 == SimpleString("Hello"), "Assignment operator should copy string data");

    // Test ostream overload
    std::cout << "SimpleString output (should be 'Hello'): " << s4 << std::endl;

    std::cout << "Finished running SimpleString tests.\n";
    return 0;
}
